package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * AnsibleHostSpec
 */
public class AnsibleHostSpec {
    public static enum HostType {
        /**
         * Add a node to the RSpec to run ansible on.
         */
        ADD,
        /**
         * Use an existing node in the RSpec to run ansible on.
         */
        EXISTING,
        /**
         * Use the local node, not in the experiment, to run ansible on.
         */
        LOCAL }

    @Nonnull public final HostType hostType;
    @Nullable public final String nodeName;
    @Nonnull public final List<UploadSpec> uploadLists;
    @Nonnull public final List<ExecuteSpec> executeLists;
    @Nullable public final String galaxyCommand;
    @Nullable public final String playbookCommand;

    public AnsibleHostSpec(@Nonnull HostType hostType,
                           @Nullable String nodeName,
                           @Nullable List<UploadSpec> uploadLists,
                           @Nullable List<ExecuteSpec> executeLists,
                           @Nullable String galaxyCommand,
                           @Nullable String playbookCommand) {
        this.hostType = hostType;
        this.nodeName = nodeName;
        this.uploadLists = uploadLists == null ? Collections.emptyList() : Collections.unmodifiableList(new ArrayList<>(uploadLists));
        this.executeLists = executeLists == null ? Collections.emptyList() : Collections.unmodifiableList(new ArrayList<>(executeLists));
        this.galaxyCommand = galaxyCommand;
        this.playbookCommand = playbookCommand;

        switch (hostType) {
            case ADD:
            case EXISTING:
            {
                if (nodeName == null)
                    throw new IllegalArgumentException(
                            "nodeName is required for ansible host of type "+hostType);
                break;
            }
        }
    }
}
