package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * ExperimentSpecification
 */
public class ExperimentSpecification {
    public enum Flavor { BASIC, ADVANCED };

    @Nonnull private final String versionBase;
    @Nonnull private final Flavor versionFlavor;
    @Nonnull private final List<String> extensions;

    @Nonnull private final List<RspecSpec> rspecs;
    @Nonnull private final List<DirSpec> dirs;
    @Nonnull private final List<UploadSpec> uploads;
    @Nonnull private final List<ExecuteSpec> executes;
    @Nullable private final AnsibleSpec ansible;

    public ExperimentSpecification(@Nonnull String versionBase,
                                   @Nonnull Flavor versionFlavor,
                                   @Nonnull List<String> extensions,
                                   @Nonnull List<RspecSpec> rspecs,
                                   @Nonnull List<DirSpec> dirs,
                                   @Nonnull List<UploadSpec> uploads,
                                   @Nonnull List<ExecuteSpec> executes,
                                   @Nullable AnsibleSpec ansible) {
        this.versionBase = versionBase;
        this.versionFlavor = versionFlavor;
        this.extensions = Collections.unmodifiableList(new ArrayList<>(extensions));

        assert rspecs.size() == 1;

        this.rspecs = Collections.unmodifiableList(new ArrayList<>(rspecs));
        this.dirs = Collections.unmodifiableList(new ArrayList<>(dirs));
        this.uploads = Collections.unmodifiableList(new ArrayList<>(uploads));
        this.executes = Collections.unmodifiableList(new ArrayList<>(executes));
        this.ansible = ansible;
    }

    @Nonnull
    public String getVersionFull() {
        return versionBase+"-"+versionFlavor.name().toLowerCase();
    }

    @Nonnull
    public String getVersionBase() {
        return versionBase;
    }

    @Nonnull
    public Flavor getVersionFlavor() {
        return versionFlavor;
    }

    @Nonnull
    public List<String> getExtensions() {
        return extensions;
    }

    @Nonnull
    public List<RspecSpec> getRspecs() {
        return rspecs;
    }

    @Nonnull
    public List<DirSpec> getDirs() {
        return dirs;
    }

    @Nonnull
    public List<UploadSpec> getUploads() {
        return uploads;
    }

    @Nonnull
    public List<ExecuteSpec> getExecutes() {
        return executes;
    }

    @Nullable
    public AnsibleSpec getAnsible() {
        return ansible;
    }
}
